
# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


import os.path

readme = ''
here = os.path.abspath(os.path.dirname(__file__))
readme_path = os.path.join(here, 'README.rst')
if os.path.exists(readme_path):
    with open(readme_path, 'rb') as stream:
        readme = stream.read().decode('utf8')


setup(
    long_description=readme,
    name='multiplex',
    version='0.5.1',
    description='View output of multiple processes, in parallel, in the console, with an interactive TUI',
    python_requires='==3.*,>=3.7.0',
    project_urls={"homepage": "https://github.com/dankilman/multiplex", "repository": "https://github.com/dankilman/multiplex"},
    author='Dan Kilman',
    author_email='dankilman@gmail.com',
    license='MIT',
    entry_points={"console_scripts": ["mp = multiplex.main:main"]},
    packages=['multiplex'],
    package_dir={"": "src"},
    package_data={},
    install_requires=['aiofiles==0.*,>=0.5.0', 'aiostream==0.*,>=0.4.1', 'click==7.*,>=7.1.2', 'easy-ansi==0.*,>=0.3.0', 'pyte==0.*,>=0.8.0'],
    extras_require={"dev": ["ansicolors==1.*,>=1.1.8", "black==20.*,>=20.8.0.b1", "pytest==5.*,>=5.2.0", "pytest-asyncio==0.*,>=0.14.0"]},
)
